@@ -60,10 +60,10 @@ class VerticaToHiveOperator(BaseOperator):
         :ref:`Hive CLI connection id <howto/connection:hive_cli>`.
     """
 
-    template_fields: Sequence[str] = ('sql', 'partition', 'hive_table')
-    template_ext: Sequence[str] = ('.sql',)
-    template_fields_renderers = {'sql': 'sql'}
-    ui_color = '#b4e0ff'
+    template_fields: Sequence[str] = ("sql", "partition", "hive_table")
+    template_ext: Sequence[str] = (".sql",)
+    template_fields_renderers = {"sql": "sql"}
+    ui_color = "#b4e0ff"
 
     def __init__(
         self,
@@ -74,8 +74,8 @@ class VerticaToHiveOperator(BaseOperator):
         recreate: bool = False,
         partition: dict | None = None,
         delimiter: str = chr(1),
-        vertica_conn_id: str = 'vertica_default',
-        hive_cli_conn_id: str = 'hive_cli_default',
+        vertica_conn_id: str = "vertica_default",
+        hive_cli_conn_id: str = "hive_cli_default",
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
@@ -97,14 +97,14 @@ class VerticaToHiveOperator(BaseOperator):
         https://github.com/uber/vertica-python/blob/master/vertica_python/vertica/column.py
         """
         type_map = {
-            5: 'BOOLEAN',
-            6: 'INT',
-            7: 'FLOAT',
-            8: 'STRING',
-            9: 'STRING',
-            16: 'FLOAT',
+            5: "BOOLEAN",
+            6: "INT",
+            7: "FLOAT",
+            8: "STRING",
+            9: "STRING",
+            16: "FLOAT",
         }
-        return type_map.get(vertica_type, 'STRING')
+        return type_map.get(vertica_type, "STRING")
 
     def execute(self, context: Context):
         hive = HiveCliHook(hive_cli_conn_id=self.hive_cli_conn_id)
@@ -115,11 +115,11 @@ class VerticaToHiveOperator(BaseOperator):
         cursor = conn.cursor()
         cursor.execute(self.sql)
         with NamedTemporaryFile("w") as f:
-            csv_writer = csv.writer(f, delimiter=self.delimiter, encoding='utf-8')
+            csv_writer = csv.writer(f, delimiter=self.delimiter, encoding="utf-8")
             field_dict = OrderedDict()
             for col_count, field in enumerate(cursor.description, start=1):
                 col_position = f"Column{col_count}"
-                field_dict[col_position if field[0] == '' else field[0]] = self.type_map(field[1])
+                field_dict[col_position if field[0] == "" else field[0]] = self.type_map(field[1])
             csv_writer.writerows(cursor.iterate())
             f.flush()
             cursor.close()
